/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package javax.tools.diagnostics.vm;


/**
 * <p>
 * Definition of the capabilities of a Dump that should be produced by
 * passing an instance of this descriptor to the Dump class
 * 
 * 
 * @experimental This is an experimental addition to the API and is subject to
 *               change
 * 
 */
public class DumpDescriptor implements Cloneable {
	
	private boolean recordClassLoaders=false;
	private boolean recordClasses=false;
	/**
	 * Call to indicate that the dump generated by the initiator is required to
	 * contain data that will eventually be represented by the JavaClassLoader interface
	 * 
	 */
	public void setRecordClassLoaders() {
		recordClassLoaders=true;
	}
	
	
	/**
	 * Call to indicate that the dump generated by the initiator is required to
	 * contain data that will eventually be represented by the JavaClass interface
	 * 
	 */
	
	public void setRecordClasses() {
		recordClasses=true;
	}

	/**
	 * Returns true if the recording of class loaders in the generated dump
	 * is a required attribute.  Returns false if it is optional.
	 * @return
	 */
	public boolean recordClassLoadersRequired() {
		return recordClassLoaders;
	}


	public boolean recordClassesRequired() {
		return recordClasses;
	}


	/**
	 * Returns a copy of this descriptor.
	 * 
	 * @return new copy.
	 */
	public DumpDescriptor copy() { 
		 
		try {
			return (DumpDescriptor) clone();
		} catch (CloneNotSupportedException e) {
			
			e.printStackTrace();
		}
		return null;
	
	}


	@Override
	protected Object clone() throws CloneNotSupportedException {
		
		return super.clone();
	}
	
}
