/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package javax.tools.diagnostics.vm.spi.delegates;

import java.io.IOException;
import java.lang.reflect.Method;

import javax.tools.diagnostics.vm.DumpDescriptor;
import javax.tools.diagnostics.vm.DumpHandle;
import javax.tools.diagnostics.vm.DumpInitiatorDelegate;
import javax.tools.diagnostics.vm.spi.DumpInitiatorCapabilities;

/**
 * Dump Delegate for IBM JVMs using the com.ibm.jvm.Dump API Note that
 * reflection is used to trigger a dump as otherwise compilation of this
 * code would be dependent on having an IBM JVM.
 * 
 */
public abstract class AbstractIBMSPIBasedDumpInitiatorDelegate implements
		DumpInitiatorDelegate {

	private static final String COM_IBM_JVM_DUMP = "com.ibm.jvm.Dump";
	private Method dumpMethod = null;

	

	public boolean available() {

		try {
			// does class exist?
			Class clazz = Class.forName(COM_IBM_JVM_DUMP);
			String requiredMethod=getMethodName();
			// store the dump method for later use
			dumpMethod = clazz.getMethod(requiredMethod, new Class[0]);
			return true;

		} catch(ClassNotFoundException cnfe) {
			return false;
		}
		catch (Exception e) {
			e.printStackTrace();
			return false;
		}

	}

	protected abstract String getMethodName();

	@Override
	public DumpHandle createDumpHandle() {
		return new DumpHandle() {
			
			@Override
			public boolean dump() throws IOException {
				try {
					dumpMethod.invoke(null, new Object[0]);
					return true;
				} catch (Exception e) {
					throw new IOException("dump failed", e);
				}
				
			}
		};
	}

	@Override
	public DumpHandle createDumpHandle(DumpDescriptor descriptor) {
		return new DumpHandle() {
			
			@Override
			public boolean dump() throws IOException {
				try {
					dumpMethod.invoke(null, new Object[0]);
					return true;
				} catch (Exception e) {
					throw new IOException("dump failed", e);
				}
				
			}
		};
	}

}