/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package javax.tools.diagnostics.runtime.java;

import java.util.List;

import javax.tools.diagnostics.image.ImageSection;


/**
 * <p>
 * Represents a method or constructor in a class
 */
public interface JavaMethod extends JavaMember {

    /**
     * <p>
     * Get the set of ImageSections containing the bytecode of this method.
     * <p>
     * Each ImageSection contains data (usually bytecodes) used
     * in executing this method in interpreted mode. 
     * <p>
     * The collection may be empty for native methods, or
     * pre-compiled methods.
     * <p>
     * Typically, the collection will contain no more than one
     * section, but this is not guaranteed.
     *  
     * <p>The returned list follows the standard semantics for javax.tools.diagnostics collections.</p>
     * <p>The returned list is never null but could be empty.</p>
     * @return a list of ImageSections.
     * 
     * 
     * @see javax.tools.diagnostics.image.ImageSection
     */
    List<ImageSection> getBytecodeSections();

    /**
     * <p>
     * Get the set of ImageSections containing the compiled code of this method.
     * <p>
     * Each ImageSection contains data (usually executable code) used
     * in executing this method in compiled mode.
     * <p>The returned list follows the standard semantics for javax.tools.diagnostics collections.</p>
     * <p>The returned list is never null but could be empty.</p>
     * 
     * @return a list of ImageSections.
     * 
     * @see javax.tools.diagnostics.image.ImageSection
     * 
     */
    List<ImageSection> getCompiledSections();
    
    
    /**
     * <p>
     * An experimental addition to the API.
     * <p>
     * Get the set of {@link JavaVariable} objects
     * <p>The returned list follows the standard semantics for javax.tools.diagnostics collections.</p>
     * <p>The returned list is never null but could be empty.</p>
     * 
     * @return List of JavaVariable objects available
     *  
     */
    List<JavaVariable> getVariables();  
    
	/**
	 * @param obj
	 * @return True if the given object refers to the same JavaMethod in the image
	 */
	public boolean equals(Object obj);
	public int hashCode();
}
