/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.jvmti.javaruntime.model;

import java.util.Collections;
import java.util.LinkedList;
import java.util.List;

import junit.framework.TestCase;

/**
 * Some simple tests for ObjectMapList.
 * Ensures that the map and the list behave properly.
 * 
 */
public class ObjectMapListTest extends TestCase {

	
	ObjectMapList<Long,Long> oml;
	
	protected void setUp() throws Exception {
		super.setUp();
		oml = new ObjectMapList<Long,Long>();
	}

	protected void tearDown() throws Exception {
		super.tearDown();
	}

	public void addValues() {
		oml.put(new Long(1), new Long(2));
		oml.put(new Long(3), new Long(4));
		oml.put(new Long(5), new Long(6));	
	}
	
	public void testUnmodifiableValuesAdd() {
		addValues();
		
		List<Long> values = oml.values();
		
		try{
			values.add(new Long(7));
			fail("values.add(value) should throw UnsupportedOperationException");
		} catch(UnsupportedOperationException e) {
			// expected
		}		
	}

	public void testGet1() {
		addValues();
		
		assertEquals(new Long(2), oml.get(new Long(1)));
	}
	
	public void testGet3() {
		addValues();
		
		assertEquals(new Long(4), oml.get(new Long(3)));
	}
	
	public void testGet5() {
		addValues();
		
		assertEquals(new Long(6), oml.get(new Long(5)));
	}
	
	public void testValuesContents() {
		addValues();

		// Copy the list.
		List<Long> list = new LinkedList<Long>(oml.values());

		// So we can sort it.
		Collections.sort(list);
		
		assertEquals(new Long(2), list.remove(0));
		assertEquals(new Long(4), list.remove(0));
		assertEquals(new Long(6), list.remove(0));		
	}
	
	public void testGetNull() {
		try{
			oml.get(null);
			fail("Get with null key did not throw NPE");
		} catch (NullPointerException e) {
			// Expected			
		}

	}

	public void testPutNullValue() {
		try{
			oml.put(new Long(1), null);
			fail("Put with null value did not throw NPE");
		} catch (NullPointerException e) {
			// Expected
		}
	}
	
	public void testPutNullKey() {
		try{
			oml.put(null, new Long(1));
			fail("Put with null key did not throw NPE");
		} catch (NullPointerException e) {
			// Expected			
		}
	}
}
