/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.common;

public class  ArrayBitMaskMappingStrategy {
	
	private int arraySize=0;
	private int bitshift=0;
	private int bucketSize=0; 
	private int mask=0;
	
	public ArrayBitMaskMappingStrategy(int arraySize,int bucketSize) {
		
		this.arraySize=arraySize;
		bitshift=(int) (Math.log10(bucketSize-1)/Math.log10(2));
		mask   = (1 << (bitshift+1))-1;
		this.bucketSize = mask+1;
	}

	
	public ArrayBitMaskMappingStrategy  doubleCapacity() {
		
		if(bucketSize*2<2) return null;
		
		return new ArrayBitMaskMappingStrategy(arraySize,bucketSize*2);
	}
	
	public int getArraySize() {
		return arraySize;
	}

	public int getBitshift() {
		return bitshift;
	}

	public int getBucketSize() {
		return bucketSize;
	}

	
	/**
	 * Returns -1 if index does not map to an array element 
	 * 
	 * @param index
	 * @return element array no or -1
	 */
	public int getIndexArrayElement(int index) {
		
		int loc= index >> (bitshift+1);
		if(loc>=arraySize) return -1;
		return loc;
	}

	/**
	 * Returns -1 if index does not map to an array element 
	 * 
	 * @param index
	 * @return element seek no or -1
	 */
	public int getSeekCount(int index) {
		if(getIndexArrayElement(index)== -1 ) return -1;
		return index & mask;
	}
}