/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.common;

import java.io.IOException;
import java.util.List;

public class SubsetDataProvider implements IDataProvider {

	private IDataProvider provider=null;
	private boolean moved=true;
	private long startPoint=0;
	private long scope=0;
	private long current=0;
	
	public SubsetDataProvider(IDataProvider provider, long range) throws IOException {
		if(provider==null) throw new IllegalArgumentException("Provider is null");
		if(range<0) throw new IllegalArgumentException("range "+range+" is less than 0");
		this.provider=provider;
		startPoint=provider.getCurrentLocation();
		scope=range;
	}
	public SubsetDataProvider(IDataProvider provider,long offsetm, long range) throws IOException {
		if(provider==null) throw new IllegalArgumentException("Provider is null");
		if(range<0) throw new IllegalArgumentException("range "+range+" is less than 0");
		this.provider=provider;
		startPoint=offsetm;
		scope=range;
	}
	public long getCurrentLocation() throws IOException {
		return current;
	}

	public long getDataLength() throws IOException {
		return scope;
	}

	public void moveBy(int left) throws IOException {
		current+=left;
		moved=true;
		if(current>scope) throw new IOException("moving "+left+" is out of range "+scope);
		
	}

	public void moveTo(long l) throws IOException {
		if(current==l) return; // nothing to do
		current=l;
		moved=true;
		if(current>scope) throw new IOException("moving "+l+" is out of range "+scope);
		
	}

	public short readByte() throws IOException {
		updateLocation();
		current+=1;
		if(current>scope) throw new IOException("reading is out of range "+scope);
		return provider.readByte();
		
		
	}

	public byte[] readBytes(int left) throws IOException {
		updateLocation();
		current+=left;
		if(current>scope) throw new IOException("reading "+left+" is out of range "+scope);
		return provider.readBytes(left);
	}

	public String readCString() throws IOException {
		updateLocation();
		String string=provider.readCString();
		current=provider.getCurrentLocation();
		if(provider.getCurrentLocation()-startPoint>scope) throw new IOException("reading is out of range "+scope);
		return string;
	}

	public int readU4() throws IOException {
		updateLocation();
		current+=4;
		if(current>scope) throw new IOException("reading is out of range "+scope);
		return provider.readU4();
	}

	public long readU8() throws IOException {
		updateLocation();
		current+=8;
		if(current>scope) throw new IOException("reading is out of range "+scope);
	
		return provider.readU8();
	}

	@Override
	public void close() throws IOException {
		// TODO Auto-generated method stub
		
	}

	@Override
	public void open() throws IOException {
		// TODO Auto-generated method stub
		
	}

	@Override
	public short readU2() throws IOException {
		updateLocation();
		current+=2;
		if(current>scope) throw new IOException("reading is out of range "+scope);
		return provider.readU2();
	}

	private void updateLocation() throws IOException {
		if(moved()) {
			provider.moveTo(current+startPoint);
			moved=false;
		}
		
	}

	@Override
	public void addState(List state) {
		
		state.add("SubsetProvider moved="+moved+",startPoint="+startPoint+",scope="+scope+",current="+current);
		provider.addState(state);
	}
	@Override
	public long dataRemaining() {
		
		return scope-current;
	}
	
	@Override
	public boolean moved() {
		return moved | provider.moved();
	}
	
}
