/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.hprof.java;

import java.util.List;
import java.util.Vector;

import javax.tools.diagnostics.image.CorruptDataException;
import javax.tools.diagnostics.image.ImagePointer;
import javax.tools.diagnostics.runtime.java.JavaClass;
import javax.tools.diagnostics.runtime.java.JavaClassLoader;
import javax.tools.diagnostics.runtime.java.JavaObject;

import org.apache.kato.hprof.image.ImagePointerImpl;

/**
 * There aren't any primitive types in hprof dumps.
 * We have to fake them.
 * 
 *
 */
public class JavaPrimitiveClassImpl implements JavaClass {
	private String name;
	private ImagePointer id;
	private JavaClassLoader loader;
	
	public JavaPrimitiveClassImpl(String name, ImagePointer id, JavaClassLoader loader) {
		this.name = name;
		this.id = id;
		this.loader = loader;
	}
	
	@Override
	public JavaClassLoader getClassLoader() throws CorruptDataException {
		return loader;
	}

	@Override
	public JavaClass getComponentType() throws CorruptDataException {
		throw new IllegalArgumentException("Primitive class is not an array. There is no component type");
	}

	@Override
	public List getConstantPoolReferences() {
		return new Vector(0);
	}

	@Override
	public List getDeclaredFields() {
		return new Vector(0);
	}

	@Override
	public List getDeclaredMethods() {
		return new Vector(0);
	}

	
	@Override
	public ImagePointer getID() {
		// Use basic type id as the id.
		return id;
	}

	@Override
	public List getInterfaces() {
		return new Vector(0);
	}

	@Override
	public int getModifiers() throws CorruptDataException {
		return 0;
	}

	@Override
	public String getName() throws CorruptDataException {
		return name;
	}

	/**
	 * Primitive type have no superclass - not even java/lang/Object.
	 */
	@Override
	public JavaObject getObject() throws CorruptDataException {
		return null;
	}

	@Override
	public List getReferences() {
		return new Vector(0);
	}

	@Override
	public JavaClass getSuperclass() throws CorruptDataException {
		return null;		
	}

	@Override
	public boolean isArray() throws CorruptDataException {
		return false;
	}
}
