/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.hprof.java;

import java.util.LinkedList;
import java.util.List;

import javax.tools.diagnostics.image.CorruptDataException;
import javax.tools.diagnostics.image.ImagePointer;
import javax.tools.diagnostics.runtime.java.JavaClass;
import javax.tools.diagnostics.runtime.java.JavaClassLoader;
import javax.tools.diagnostics.runtime.java.JavaObject;


/**
 * A JavaClass implementation for when there are primitive arrays, but no classes
 * to represent them. 
 *
 */
public class JavaSyntheticPrimitiveArrayImpl implements JavaClass {
	private JavaPrimitiveClassImpl componentType;
	private String name;
	private JavaClassLoaderImpl loader;
	
	public JavaSyntheticPrimitiveArrayImpl(JavaPrimitiveClassImpl javaPrimitiveClassImpl, String name, JavaClassLoaderImpl loader) {
		this.componentType = javaPrimitiveClassImpl;
		this.name = name;
		this.loader = loader; 
	}

	public JavaClassLoader getClassLoader() throws CorruptDataException {
		return loader;
	}

	public JavaClass getComponentType() throws CorruptDataException {
		return componentType;
	}

	public List getConstantPoolReferences() {
		return new LinkedList();
	}

	public List getDeclaredFields() {
		return new LinkedList();
	}

	public List getDeclaredMethods() {
		return new LinkedList();
	}

	public ImagePointer getID() {
		return componentType.getID();
	}

	public List getInterfaces() {
		return new LinkedList();
	}

	public int getModifiers() throws CorruptDataException {
		return 0;
	}

	public String getName() throws CorruptDataException {
		return name;
	}

	public JavaObject getObject() throws CorruptDataException {
		return null;
	}

	public List getReferences() {
		return new LinkedList();
	}

	public JavaClassImpl getSuperclass() throws CorruptDataException {
		return null;
	}

	public boolean isArray() throws CorruptDataException {
		return true;
	}

}
