/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.hprof.java;

import java.util.Iterator;

import javax.tools.diagnostics.runtime.java.JavaClass;

import junit.framework.TestCase;

import org.apache.kato.hprof.image.ImagePointerImpl;

/**
 * Tests the dummy class for representing dummy types.
 * There is nothing to this class, except it's name ID and loader.
 */
public class JavaPrimitiveClassImplTest extends TestCase {
	JavaPrimitiveClassImpl instance;
	static String className = "name";
	static int id = 10;
	
	public void setUp() {
		instance = new JavaPrimitiveClassImpl(className, new ImagePointerImpl(id,null) , null);
	}
	
	public void testName() throws Exception {
		assertEquals(className, instance.getName());
	}
	
	public void testSuperClass() throws Exception {
		assertNull(instance.getSuperclass());
	}
	
	public void testIsArray() throws Exception {
		assertFalse(instance.isArray());
	}
	
	public void testGetObject() throws Exception {
		assertNull(instance.getObject());
	}
	
	public void testGetModifiers() throws Exception {
		assertEquals(0, instance.getModifiers());
	}
	
	public void testGetID() throws Exception {
		assertEquals(id, instance.getID().getAddress());
	}
	
	public void getComponentType() throws Exception {
		try{
			JavaClass clazz = instance.getComponentType();
			
			fail("Expected IllegalArgumentException from getComponentType(), got " + clazz);
		}catch(IllegalArgumentException e) {
			// Expected
		}
	}
	
	public void testGetConstantPoolReferences() throws Exception {
		Iterator iter = instance.getConstantPoolReferences().iterator();
		
		assertNotNull(iter);
		
		assertFalse(iter.hasNext());		
	}
	
	public void testGetDeclaredFields() throws Exception {
		Iterator iter = instance.getDeclaredFields().iterator();
		
		assertNotNull(iter);
		
		assertFalse(iter.hasNext());		
	}
	
	public void testGetDeclaredMethods() throws Exception {
		Iterator iter = instance.getDeclaredMethods().iterator();
		
		assertNotNull(iter);
		
		assertFalse(iter.hasNext());		
	}
	
	
	public void testGetInterfaces() throws Exception {
		Iterator iter = instance.getInterfaces().iterator();
		
		assertNotNull(iter);
		
		assertFalse(iter.hasNext());		
	}

	public void testGetReferences() throws Exception {
		Iterator iter = instance.getReferences().iterator();
		
		assertNotNull(iter);
		
		assertFalse(iter.hasNext());		
	}
	
}
