/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package test.apache.kato.hprof.image;

import java.io.IOException;

import javax.tools.diagnostics.image.CorruptDataException;
import javax.tools.diagnostics.image.DataUnavailable;
import javax.tools.diagnostics.image.ImageAddressSpace;
import javax.tools.diagnostics.image.ImagePointer;
import javax.tools.diagnostics.image.MemoryAccessException;


public class TestImagePointer extends AbstractHProfTestCase {

	ImageAddressSpace space;
	ImagePointer pointer1;
	static final long address1 = 0xfefeededdcdccbcbL;
	
	public void setUp() throws IOException {
		space = getFirstAddressSpace();
		pointer1 = space.getPointer(address1);
	}
	
	public void testGetAddress() throws Exception {
		assertEquals(address1, pointer1.getAddress());
	}
	
	public void testAdd() throws Exception {
		ImagePointer pointer2 = pointer1.add(7);
		
		assertEquals(address1+7, pointer2.getAddress());
	}
	
	public void testIsExecutable() throws Exception {
		try {			
			pointer1.isExecutable();
			fail("DataUnavailable should be thrown.");
		} catch (DataUnavailable e) {
			// Expected
		}
	}
	
	public void testIsReadOnly() throws Exception {
		try {
			pointer1.isReadOnly();
			fail("DataUnavailable should be thrown.");
		} catch (DataUnavailable e) {
			// Expected
		}
	}
	public void testIsShared() throws Exception {
		try {			
			pointer1.isShared();
			fail("DataUnavailable should be thrown.");
		} catch (DataUnavailable e) {
			// Expected
		}
	}
	
	public void testGetAddressSpace() throws Exception {
		assertEquals(space, pointer1.getAddressSpace());
	}
	
	public void testGetByteAt() throws Exception {
		try {
			pointer1.getByteAt(0);
			fail("Expected MemoryAccessException");
		} catch (MemoryAccessException e) {
			// expected
		} catch (CorruptDataException e) {
			fail("Expected MemoryAccessException");
		}
	}
	
	public void testGetDoubleAt() throws Exception {
		try {
			pointer1.getDoubleAt(0);
			fail("Expected MemoryAccessException");
		} catch (MemoryAccessException e) {
			// expected
		} catch (CorruptDataException e) {
			fail("Expected MemoryAccessException");
		}
	}
	
	public void testGetFloatAt() throws Exception {
		try {
			pointer1.getFloatAt(0);
			fail("Expected MemoryAccessException");
		} catch (MemoryAccessException e) {
			// expected
		} catch (CorruptDataException e) {
			fail("Expected MemoryAccessException");
		}
	}
	
	public void testGetIntAt() throws Exception {
		try {
			pointer1.getIntAt(0);
			fail("Expected MemoryAccessException");
		} catch (MemoryAccessException e) {
			// expected
		} catch (CorruptDataException e) {
			fail("Expected MemoryAccessException");
		}
	}
	
	public void testGetLongAt() throws Exception {
		try {
			pointer1.getLongAt(0);
			fail("Expected MemoryAccessException");
		} catch (MemoryAccessException e) {
			// expected
		} catch (CorruptDataException e) {
			fail("Expected MemoryAccessException");
		}
	}
	
	public void testGetShortAt() throws Exception {
		try {
			pointer1.getShortAt(0);
			fail("Expected MemoryAccessException");
		} catch (MemoryAccessException e) {
			// expected
		} catch (CorruptDataException e) {
			fail("Expected MemoryAccessException");
		}
	}

	public void testGetPointerAt() throws Exception {
		try {
			pointer1.getPointerAt(0);
			fail("Expected MemoryAccessException");
		} catch (MemoryAccessException e) {
			// expected
		} catch (CorruptDataException e) {
			fail("Expected MemoryAccessException");
		}
	}
	
	public void testEqualsNull() throws Exception {
		assertFalse(pointer1.equals(null));
	}
	
	public void testEqualsString() throws Exception {
		assertFalse(pointer1.equals("Hello"));
	}
	
	public void testEqualsSelf() throws Exception {
		assertTrue(pointer1.equals(pointer1));		
	}
	
	public void testEqualsLike() throws Exception {
		ImagePointer pointer2 = space.getPointer(address1);
		
		assertTrue(pointer1.equals(pointer2));
	}
	
	public void testEqualsDifferent() throws Exception {
		ImagePointer pointer2 = space.getPointer(0x2983474);
		
		assertFalse(pointer1.equals(pointer2));
	}
	
	public void testHashCode() throws Exception {
		ImagePointer pointer2 = space.getPointer(address1);
		assertEquals(pointer1.hashCode(), pointer2.hashCode());
	}
	
	
}
