
/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/


#include "cjvmti.h"
#include "addObject.h"
#include "addClass.h"
#include "addField.h"

struct JObject * addObject(jobject obj, int depth) {
	int i;
	jlong tag;
	jvmtiError err;
	jclass class;
	struct JClass * clazz;
	struct JClass * tempClazz;
	struct JObject * objp = NULL;
	FPOS_T fieldValLoc;
	jint totalFieldCount;
	int classObject = 0;
	
	if (maxReferenceDepth != 0 && maxReferenceDepth <= depth){
		return &nullObject; // We have followed to max reference depth so return null
	}
	
	// Cover all cases of null classes / jni references / invalid classes

	if (obj == NULL) return &nullObject; // Unexpected.

	// Check if we have already referenced this object
	err = (*env)->GetTag(env, obj, &tag);
	if (tag == 0){
		class = (*jniptr)->GetObjectClass(jniptr, obj);
		if (class == NULL){
			(*jniptr)->DeleteLocalRef(jniptr, obj);
			(*jniptr)->DeleteLocalRef(jniptr, class);
			return &nullObject;
		}
		clazz = addClassDetails(class);
	}else{
		class = (*jniptr)->GetObjectClass(jniptr, obj);
		clazz = addClassDetails(class);
		//(*jniptr)->DeleteLocalRef(jniptr, class);
	}


	if (obj == NULL || class == NULL) return &nullObject; // Unexpected

	if (clazz == NULL){
		return &nullObject;
	}

	if (clazz->positionInFile == 0) {
		objp = (void *) clazz;
		printf("Invalid class location %p %lld %lld \n", clazz,
				objp->positionInFile, clazz->positionInFile);
		printf(" %s, abort \n ", clazz->name);
		abort();
	}

	// Check if what is tagged is actually a class object and needs filling in
	if (tag != 0) {
		objp = (void *) tag;
		if (!objp->state) { // Check it has not previously been filled in 
			objp->type = CLASS;
			classObject = 1;
		}else{
			if (objp->depth > depth && maxReferenceDepth != 0){ // Check depth is not lower from this reference
				objp->depth = depth;
				//printf("Lower depth from here %d %s ! \n", objp->state, clazz->name);
				objp->state = 1;}
			return objp;
		}
	}

	if (tag == 0 || classObject) {
		if (!classObject)
			tag = (jlong) calloc(1, sizeof(struct JObject));

		if ((void *) tag == NULL) {
			printf("Failed to malloc object \n");
			abort();
		}

		if (!classObject){
			err = (*env)->SetTag(env, obj, tag);
			Q_enqueue(&obj, toDetag); // Add object to deallocation queue
		}

		if (err != JVMTI_ERROR_NONE) { // Check tag was set
			printf("JVMTI Error %d \n", err);
			return objp;
		}

		FSEEK(variableFile, 0, SEEK_END);

		// Work out how many fields we need to save across the hierarchy
		tempClazz = clazz;
		totalFieldCount = 0;
		while (tempClazz) {
			totalFieldCount += tempClazz->numInstanceFields;
			tempClazz = tempClazz->superClass;
		}

		objp = (void *) tag; // Set pointer
		if (!classObject) objp->type = OBJECT;

		objp->state = 1; // Indicates object has been written (but references not followed)

		if (maxReferenceDepth!=0)objp->depth = depth; // Set reference depth

		FSEEK(variableFile, 0, SEEK_END);
		objp->positionInFile = FTELL(variableFile);

		// Prepare space in dump file
		writeIDNoSize(CJVMTI_OBJECT, variableFile);
		writeReference(clazz->positionInFile, variableFile);
		writeJint(totalFieldCount, variableFile);
		fieldValLoc = FTELL(variableFile);
		for (i = 0; i < totalFieldCount; i++) {
			fwrite(&waitingToBeWritten, sizeof(FPOS_T), 1, variableFile);
		}

		objp->referenceLocation = fieldValLoc; // used to write references into file
		objp->totalFieldCount = totalFieldCount; // used to write references into file
		FSEEK(variableFile, 0, SEEK_END);
		objectCount++;
		Q_enqueue(&obj, qObjects); // Queue this object to have its references followed
	}
	return objp;
}

struct JObject * getObjectReferences(jobject obj) {
	int i;
	FPOS_T fieldValLoc;
	FPOS_T fieldValue;
	jlong tag;
	jclass tempClass;
	struct JObject * objp;
	struct JClass * clazz;
	struct JClass * tempClazz;
	int totalFieldCount;

	(*env)->GetTag(env, obj, &tag);
	objp = (struct JObject *) tag;
	if (objp->state == 2) { // Already had its reference resolved
		objectCount--;
		return objp;
	}

	tempClass = (*jniptr)->GetObjectClass(jniptr, obj);
	clazz = addClassDetails(tempClass);
	(*jniptr)->DeleteLocalRef(jniptr, tempClass);
	totalFieldCount = objp->totalFieldCount;
	fieldValLoc = objp->referenceLocation;
	FSEEK(variableFile, 0, SEEK_END);

	// Loop through saving the references to file
	tempClazz = clazz;
	while (tempClazz) {
		for (i = 0; i < tempClazz->numInstanceFields; i++) {
			fieldValue = addFieldValue(CJVMTI_INSTANCE_VAR, obj,
					tempClazz->instanceFields[i],
					tempClazz->instanceFieldSignatures[i], 0, 0, 0, objp->depth+1);
			if (fieldValue == waitingToBeWritten){
				printf("Error unwritten reference\n");
				abort();
			}
			FSETPOS(variableFile, &fieldValLoc);
			writeReference(fieldValue, variableFile);
			if (fieldValue == waitingToBeWritten) {
				printf("Circular reference \n");
				abort();
			}
			fieldValLoc = FTELL(variableFile);
			FSEEK(variableFile, 0, SEEK_END);
		}
		tempClazz = tempClazz->superClass;
	}
	objectCount--;
	objp->state = 2; // Object full resolved
	printDepth--;
	return objp;
}
