/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.tck.harness;

import org.apache.kato.tck.api.TCKException;


public abstract class AbstractLauncher {

	private boolean verboseMode=true;


	public AbstractLauncher() {

		
	}
	public void log(String message) {
		if(verboseMode) {
			System.out.println(message);
		}
	}
	protected  void raiseError(String message) {
		log(message);
		throw new TCKException(message);

	}

	void raiseError(String message, Exception e) {
		log(message);
		throw new TCKException(message, e);

	}

	static int getTestType(String testtype) {
		testtype = testtype.toLowerCase().trim();
		int type = 0;
		if (testtype.equals("all")) {
			type = 1;
		} else if (testtype.equals("process")) {
			type = 2;
		} else if (testtype.equals("javaruntime")) {
			type = 3;
		} else if (testtype.equals("javaheap")) {
			type = 4;
		}
		return type;
	}

	static int getTestDumpType(String testtype) {
		testtype = testtype.toLowerCase().trim();
		int type = 0;
		if (testtype.equals("all")) {
			type = 1;
		} else if (testtype.equals("process")) {
			type = 2;
		} else if (testtype.equals("javaruntime")) {
			type = 3;
		} else if (testtype.equals("javaheap")) {
			type = 4;
		}
		return type;
	}

	
	
	

	

	private Object createInstance(String className) {

		try {
			Class clazz=Class.forName(className);
			Object instance=clazz.newInstance();
			return instance;
		} catch (ClassNotFoundException e) {

			raiseError("cannot locate class "+className,e);
		} catch (InstantiationException e) {
			raiseError("unable to instantiate "+className,e);

		} catch (IllegalAccessException e) {
			raiseError("unable to instantiate "+className,e);
		}

		return null;
	}

	
	

	public boolean isVerboseMode() {
		return verboseMode;
	}
	
	

}
