/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/

package org.apache.kato.tck.harness.scenario;

import java.lang.reflect.Method;
import java.util.LinkedList;
import java.util.List;


class CheckPointHandler {

	private List startedThreads=new LinkedList();
	private int registeredThreads=0;
	
	/**
	 * @param execute
	 */
	public CheckPointHandler() {
		
	}

	/**
	 * Thread reached completion point..
	 * 
	 */
	public void checkpoint(Method method) {

		startedThreads.remove(method);
	}

	/**
	 * 
	 */
	public void complete() {

		while (hasOutstandingThreads()) {
			try {
				Thread.sleep(1000);
			} catch (InterruptedException e) {
				;
			}
		}

	}

	/**
	 * @return
	 */
	public int getThreadCount() {
		return registeredThreads;
	}

	/**
	 * Handle new testcase configure method
	 * 
	 * Do this by creating a thread to run the method
	 * 
	 */
	public void handle(Method method, ScenarioElement testcase) {
		
		
		CheckPointRunner runner = new CheckPointRunner(this, method,
				testcase);
		
		startedThreads.add(method); // keep track of it
		registeredThreads++;
		
		Thread t = new Thread(runner, method.getDeclaringClass().getName()
				+ "#" + method.getName());
		t.start();

	}

	public boolean hasOutstandingThreads() {
		return startedThreads.size() > 0;
	}

	public int outstandingThreads() {
		return startedThreads.size();
	}

}