/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/

package org.apache.kato.tck.harness.scenario;

import java.io.IOException;

/**
 * Dump Trigger
 * 
 *  Interface used by scenario launcher to trigger
 *  dumps.  How the dump is triggered is at the
 *  discretion of the implementor.
 *  
 */
public interface IDumpTrigger {

	/**
	 * Called by the Scenario Launcher to create a Dump
	 * This method is not expected to return.
	 * If it does the Scenario Launcher will exit the JVM
	 * immediately
	 * @throws IOException 
	 */
	public void dump() throws IOException;

	/**
	 * Specify the dump format to produce
	 * 
	 * @param dumpFormat
	 */
	public void setDumpFormat(String dumpFormat);
	
}
