/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.tck.results.reporter;



import java.util.Date;
import java.util.Iterator;
import java.util.Map;
import java.util.Properties;
import java.util.TreeMap;

public class TCKResultSet {

	private String name=null;
	private String datestamp=null;
	private double time=0;
	private Properties properties=null;
	private int failures=0;
	private int errors=0;
	private String errLog="";
	private String outLog="";
	private TestExecutionConfig config=null;
	private Map results=new TreeMap();
	
	public TCKResultSet(TestExecutionConfig config, String datestamp, Properties p) {
		this.config=config;
		this.properties=p;
		this.datestamp=datestamp;
	}
	public TCKResultSet(TestExecutionConfig config, Date datestamp, Properties p) {
		this(config,datestamp.toString(),p);
	}

	public void addTestcaseResult(TestcaseResult result) {
		if(result instanceof TestcaseResultError) {
			errors++;
		}
		else if(result instanceof TestcaseResultFailure) {
			failures++;
		}
		String id=result.getLabel();
		if(results.containsKey(id)) throw new RuntimeException("duplicate test entry "+id);
		result.setResultSet(this);
		results.put(id,result);
		
		
		
	}

	
	public Iterator iterator() {
		
		return results.values().iterator();
	}

	public TestcaseResult getResult(String key) {
		return (TestcaseResult) results.get(key);
		
	}
	public String getVersion() {
		
		return config.version;
	}

	public String getOperatingSystem() {
		
		return config.os;
	}

	public String getArchitecture() {
		
		return config.arch + "-" + config.wordsize;
	}

	public String getTestSuite() {
		return config.testsuite;
		
	}

	public void setSystemOutLog(String log) {
		outLog=log;
		
	}

	public void setSystemErrLog(String log) {
		errLog=log;
		
	}

	public int getTestcaseCount() {
		return results.size();
	}

	public int getErrorCount() {
		return errors;
	}

	public int getFailureCount() {
	return failures;
	}

	public TestExecutionConfig getConfig() {
		return config;
	}

	public String getErrLog() {
		return errLog;
	}

	public void setErrLog(String errLog) {
		this.errLog = errLog;
	}

	public String getOutLog() {
		return outLog;
	}

	public void setOutLog(String outLog) {
		this.outLog = outLog;
	}
}
