/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.tck.results.reporter;

import java.util.List;


public abstract class TestcaseResult {

	private String className=null;
	private String methodName=null;
	private String[] output=null;
	private String[] err=null;
	private TCKResultSet resultSet=null;
	private long time=0;
	
	public TestcaseResult(String className, String methodName, long time) {
		
		
		this.className=className;
		this.methodName=methodName;
		this.time=time;
	}

	public String getLabel() {
		return className+" "+methodName;
	}
	public String getClassName1() {
		return className;
	}

	public String getMethodName() {
		return methodName;
	}

	public TCKResultSet getResultSet() {
		return resultSet;
	}

	public void setResultSet(TCKResultSet resultSet) {
		this.resultSet = resultSet;
	}

	public String getType() {
	
		
		if(this instanceof TestcaseResultError) return "error";
		if(this instanceof TestcaseResultFailure) return "failed";
		return "passed";
		
	}

	protected String[] convertStack(Throwable t) {
		StackTraceElement[] stack=t.getStackTrace();
		String[] results=new String[stack.length];
		for(int i=0;i<stack.length;i++) {
			results[i]=stack[i].toString();
		}
		return results;
	}

	public long getTime() {
		return time;
	}

	public void setTime(long time) {
		this.time = time;
	}

	public String[] getOutput() {
		return output;
	}

	public void setOutput(String[] output) {
		this.output = output;
	}

	public void setOutput(List lines) {
		if(lines==null || lines.isEmpty()) return;
		setOutput((String[]) lines.toArray(new String[0]));
		
	}

	public void setError(String[] erroutput) {
		this.err=erroutput;
		
	}

	public String[] getError() {
		return err;
	}
	
}
