/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.tck.scenario142.javaruntime;

import javax.tools.diagnostics.runtime.java.JavaField;
import javax.tools.diagnostics.runtime.java.JavaObject;

import org.apache.kato.tck.harness.TCKJavaRuntimeTestcase;
import org.apache.kato.tck.scenario142.javaruntime.SetupJavaField_getChar;


/**
 * Test JavaField.getChar() against various fields and values.
 * 
 */
public class TestJavaField_getChar extends TCKJavaRuntimeTestcase {
	
	SetupJavaField_getChar setup=new SetupJavaField_getChar();
	
	static JavaObject thisObject = null;	
	public JavaObject getScenerioReference() {
		if (thisObject == null) {
			thisObject = super.getScenerioReference();
		}	
		return thisObject;		
	}
	
	public void testMaxCharValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField maxCharField = getJavaField(thisJavaObject, "maxChar");
		
		char maxCharValue = maxCharField.getChar(thisJavaObject);
		
		assertEquals(setup.maxChar, maxCharValue);		
	}
	
	public void testMinCharValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField minCharField = getJavaField(thisJavaObject, "minChar");
		
		char minCharValue = minCharField.getChar(thisJavaObject);
		
		assertEquals(setup.minChar, minCharValue);		
	}

	public void testStaticMinCharValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField minCharField = getJavaField(thisJavaObject, "staticMinChar");
		
		char minCharValue = minCharField.getChar(null);
		
		assertEquals(SetupJavaField_getChar.staticMinChar, minCharValue);		
	}
	
	public void testZeroCharValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField zeroCharField = getJavaField(thisJavaObject, "zeroChar");
		
		char zeroCharValue = zeroCharField.getChar(thisJavaObject);
		
		assertEquals(setup.zeroChar, zeroCharValue);		
	}
	
	public void testPosCharValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField posCharField = getJavaField(thisJavaObject, "posChar");
		
		char posCharValue = posCharField.getChar(thisJavaObject);
		
		assertEquals(setup.posChar, posCharValue);		
	}


	public void testDoubleValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField doubleValueField = getJavaField(thisJavaObject, "doubleValue");

		try{
			char aDoubleValue = doubleValueField.getChar(thisJavaObject);
			fail("Missing illegal argument exception from JavaField.getChar(doubleValue)");
		} catch (IllegalArgumentException e) {
			// expected
		}	
	}
	
	public void testFloatValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField floatValueField = getJavaField(thisJavaObject, "floatValue");

		try{
			char aFloatValue = floatValueField.getChar(thisJavaObject);
			fail("Missing illegal argument exception from JavaField.getChar(floatValue)");
		} catch (IllegalArgumentException e) {
			// expected
		}	
	}
	
	public void testLongValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField longValueField = getJavaField(thisJavaObject, "longValue");

		try{
			char aLongValue = longValueField.getChar(thisJavaObject);
			fail("Missing illegal argument exception from JavaField.getChar(longValue)");
		} catch (IllegalArgumentException e) {
			// expected
		}	
	}
	
	public void testIntValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField intValueField = getJavaField(thisJavaObject, "intValue");

		try{
			char aIntValue = intValueField.getChar(thisJavaObject);
			fail("Missing illegal argument exception from JavaField.getChar(intValue)");
		} catch (IllegalArgumentException e) {
			// expected
		}	
	}
	
	public void testByteValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField byteValueField = getJavaField(thisJavaObject, "byteValue");

		try{
			char aByteValue = byteValueField.getChar(thisJavaObject);
			fail("Missing illegal argument exception from JavaField.getChar(byteValue)");
		} catch (IllegalArgumentException e) {
			// expected
		}	
	}
	
	public void testShortValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField shortValueField = getJavaField(thisJavaObject, "shortValue");

		try{
			char aShortValue = shortValueField.getChar(thisJavaObject);
			fail("Missing illegal argument exception from JavaField.getChar(shortValue)");
		} catch (IllegalArgumentException e) {
			// expected
		}	
	}
	public void testBooleanValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField booleanValueField = getJavaField(thisJavaObject, "booleanValue");
		
		try{
			char aBooleanValue = booleanValueField.getChar(thisJavaObject);
			fail("Missing illegal argument exception from JavaField.getChar(booleanValue)");
		} catch (IllegalArgumentException e) {
			// expected
		}
	}
	
	public void testObjectReference() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField objectReferenceField = getJavaField(thisJavaObject, "objectReference");
		
		try{
			char anObjectReference = objectReferenceField.getChar(thisJavaObject);
			fail("Missing illegal argument exception from JavaField.getChar(objectReference)");
		} catch (IllegalArgumentException e) {
			// expected
		}
	}
}
