/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.tck.scenario142.javaruntime;

import javax.tools.diagnostics.runtime.java.JavaField;
import javax.tools.diagnostics.runtime.java.JavaObject;

import org.apache.kato.tck.harness.TCKJavaRuntimeTestcase;
import org.apache.kato.tck.scenario142.javaruntime.SetupJavaField_getDouble;


/**
 * Test JavaField.getDouble() against various fields and values.
 * 
 */
public class TestJavaField_getDouble extends TCKJavaRuntimeTestcase {
	
	SetupJavaField_getDouble setup=new SetupJavaField_getDouble();
	
	static JavaObject thisObject = null;	
	public JavaObject getScenerioReference() {
		if (thisObject == null) {
			thisObject = super.getScenerioReference();
		}	
		return thisObject;		
	}
	
	public void testMaxDoubleValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField maxDoubleField = getJavaField(thisJavaObject, "maxDouble");
		
		double maxDoubleValue = maxDoubleField.getDouble(thisJavaObject);
		
		assertEquals(setup.maxDouble, maxDoubleValue, 0.0);		
	}
	
	public void testMinDoubleValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField minDoubleField = getJavaField(thisJavaObject, "minDouble");
		
		double minDoubleValue = minDoubleField.getDouble(thisJavaObject);
		
		assertEquals(setup.minDouble, minDoubleValue, 0.0);	
	}

	public void testStaticMinDoubleValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField minDoubleField = getJavaField(thisJavaObject, "staticMinDouble");
		
		double minDoubleValue = minDoubleField.getDouble(null);
		
		assertEquals(SetupJavaField_getDouble.staticMinDouble, minDoubleValue, 0.0);		
	}
	
	public void testZeroDoubleValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField zeroDoubleField = getJavaField(thisJavaObject, "zeroDouble");
		
		double zeroDoubleValue = zeroDoubleField.getDouble(thisJavaObject);
		
		assertEquals(setup.zeroDouble, zeroDoubleValue, 0.0);		
	}
	
	public void testNegDoubleValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField negDoubleField = getJavaField(thisJavaObject, "negDouble");
		
		double negDoubleValue = negDoubleField.getDouble(thisJavaObject);
		
		assertEquals(setup.negDouble, negDoubleValue, 0.0);		
	}	
	
	public void testPosDoubleValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField posDoubleField = getJavaField(thisJavaObject, "posDouble");
		
		double posDoubleValue = posDoubleField.getDouble(thisJavaObject);
		
		assertEquals(setup.posDouble, posDoubleValue, 0.0);		
	}

	public void testFloatValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField floatValueField = getJavaField(thisJavaObject, "floatValue");

		try{
			double aFloatValue = floatValueField.getDouble(thisJavaObject);
		} catch (IllegalArgumentException e) {
			fail("Unexpected illegal argument exception from JavaField.getDouble(floatValue)");
		}	
	}
	
	public void testLongValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField longValueField = getJavaField(thisJavaObject, "longValue");

		try{
			double aLongValue = longValueField.getDouble(thisJavaObject);
		} catch (IllegalArgumentException e) {
			fail("Unexpected illegal argument exception from JavaField.getDouble(longValue)");
		}	
	}
	
	public void testIntValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField intValueField = getJavaField(thisJavaObject, "intValue");

		try{
			double aIntValue = intValueField.getDouble(thisJavaObject);
		} catch (IllegalArgumentException e) {
			fail("Unexpected illegal argument exception from JavaField.getDouble(intValue)");
		}	
	}
	
	public void testByteValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField byteValueField = getJavaField(thisJavaObject, "byteValue");

		try{
			double aByteValue = byteValueField.getDouble(thisJavaObject);
		} catch (IllegalArgumentException e) {
			fail("Unexpected illegal argument exception from JavaField.getDouble(byteValue)");
		}	
	}
	
	public void testCharValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField charValueField = getJavaField(thisJavaObject, "charValue");

		try{
			double aCharValue = charValueField.getDouble(thisJavaObject);
		} catch (IllegalArgumentException e) {
			fail("Unexpected illegal argument exception from JavaField.getDouble(charValue)");
		}	
	}
	
	public void testShortValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField doubleValueField = getJavaField(thisJavaObject, "shortValue");

		try{
			double aShortValue = doubleValueField.getDouble(thisJavaObject);
		} catch (IllegalArgumentException e) {
			fail("Unexpected illegal argument exception from JavaField.getDouble(shortValue)");
		}	
	}

	
	public void testBooleanValue() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField booleanValueField = getJavaField(thisJavaObject, "booleanValue");
		
		try{
			double aBooleanValue = booleanValueField.getDouble(thisJavaObject);
			fail("Missing illegal argument exception from JavaField.getDouble(booleanValue)");
		} catch (IllegalArgumentException e) {
			// expected
		}
	}
	
	public void testObjectReference() throws Exception {
		JavaObject thisJavaObject = getScenerioReference();
		JavaField objectReferenceField = getJavaField(thisJavaObject, "objectReference");
		
		try{
			double anObjectReference = objectReferenceField.getDouble(thisJavaObject);
			fail("Missing illegal argument exception from JavaField.getDouble(objectReference)");
		} catch (IllegalArgumentException e) {
			// expected
		}
	}
}
