/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/

package org.apache.kato.tck.tests.legacy;

import java.util.List;

import javax.tools.diagnostics.image.CorruptDataException;
import javax.tools.diagnostics.image.DataUnavailable;
import javax.tools.diagnostics.image.ImagePointer;
import javax.tools.diagnostics.image.ImageSection;
import javax.tools.diagnostics.runtime.java.JavaClass;
import javax.tools.diagnostics.runtime.java.JavaHeap;
import javax.tools.diagnostics.runtime.java.JavaObject;
import javax.tools.diagnostics.runtime.java.JavaReference;
import javax.tools.diagnostics.runtime.java.JavaRuntime;

import org.apache.kato.tck.harness.TCKJavaRuntimeTestcase;

/**
 * 
 */
public class TestJavaObjects  extends TCKJavaRuntimeTestcase {

	
	public void testJavaObjects() {
		JavaRuntime runtime=getJavaRuntime();
		
		List<JavaHeap> heaps=runtime.getHeaps();
		
		if(heaps.isEmpty()) return; // no heaps to test
		
		int counter=0;
		
		for(JavaHeap heap:heaps) {
		
			List<JavaObject> objects=heap.getObjects();
			
			assertNotNull("Entry "+counter+":objects list is null",objects);
			
			int objcounter=0;
			
			for(JavaObject object:objects) {
				
				assertNotNull("Entry "+counter+"/"+objcounter+" is null",object);
				
				// test id
				
				ImagePointer p = subTestID(counter, objcounter, object);
				
				// test getSize
				
				subTestGetSize(counter, objcounter, object);
				
				
				// test get hash code
				
				subTestGetHashCode(object);
				
				// test persistent hash code
				
				subTestGetPersistentHash(object);
				
				// test get heap
				
				subTestGetObjectHeap(counter, heap, objcounter, object);
				
				
				subTestGetJavaClass(counter, objcounter, object);
			
				// test references
				
				List<JavaReference> ref=object.getReferences();
				assertNotNull("Entry "+counter+"/"+objcounter+" getReferences is null",ref);
				
				// test sections
				
				List<ImageSection> sections=object.getSections();
				assertNotNull("Entry "+counter+"/"+objcounter+" getSections is null",sections);
				
				
				
				// array tests..
				
				int isArray=0; // don't know if its an array
				
				try {
					isArray=object.isArray() ? 1 : -1 ; 
				} catch (CorruptDataException e1) {
					// allowed
				}
				
				// is an array 
				
				if(isArray==1) {
				
					subTestArrayObject(counter, objcounter, object);
						
					
					}
					
			
			// not an array 
				
			else if(isArray== -1) {
				subTestNotArrayObject(counter, objcounter, object);
					
				}
				
				//object.arraycopy(srcStart, dst, dstStart, length);
			}
				
				objcounter++;
			}
			
			counter++;
		}

	private void subTestNotArrayObject(int counter, int objcounter,
			JavaObject object) {
		try {
			object.getArraySize();
		 	fail("Entry "+counter+"/"+objcounter+" getArraySize should fail with IllegalArgumentException");
			
		} catch (CorruptDataException e) {
			// allowed
		}
		catch(IllegalArgumentException e2) {
			// allowed
		}
	}

	private void subTestArrayObject(int counter, int objcounter,
			JavaObject object) {
		try {
			int size=object.getArraySize();
		 	assertTrue("Entry "+counter+"/"+objcounter+" getArraySize is invalid (size="+size+")",size>=0);
		 
			
		} catch (CorruptDataException e) {
			// allowed
		}
		catch(IllegalArgumentException e2) {
				fail("unexpected exception received for an array");
		}
	}

	private void subTestGetJavaClass(int counter, int objcounter,
			JavaObject object) {
		try {
			JavaClass clazz=object.getJavaClass();
			assertNotNull("Entry "+counter+"/"+objcounter+" getJavaClass is null",clazz);
		} catch (CorruptDataException e3) {
			// allowed
		}
	}

	private void subTestGetObjectHeap(int counter, JavaHeap heap,
			int objcounter, JavaObject object) {
		try {
			JavaHeap parentheap=object.getHeap();
			assertNotNull("Entry "+counter+"/"+objcounter+" getHeap is null",parentheap);
			assertEquals("Entry "+counter+"/"+objcounter+" getHeap is not expected parent",heap,parentheap);
			
		} catch (CorruptDataException e3) {
			// allowed
		} catch (DataUnavailable e3) {
			// allowed
		}
	}

	private void subTestGetPersistentHash(JavaObject object) {
		try {
			object.getPersistentHashcode();
		} catch (DataUnavailable e3) {
			// allowed
		} catch (CorruptDataException e3) {
			// allowed
		}
	}

	private void subTestGetHashCode(JavaObject object) {
		try {
			object.getHashcode();
			
		} catch (DataUnavailable e3) {
			// allowed
		} catch (CorruptDataException e3) {
			// allowed
		}
	}

	private void subTestGetSize(int counter, int objcounter, JavaObject object) {
		try {
			long size=object.getSize();
			assertTrue("Entry "+counter+"/"+objcounter+" getSize() is invalid (size="+size+")",size>=0);
		} catch (CorruptDataException e3) {
			// allowed
		}
	}

	private ImagePointer subTestID(int counter, int objcounter,
			JavaObject object) {
		ImagePointer p=object.getID();
		assertNotNull("Entry "+counter+"/"+objcounter+" getID is null",p);
		return p;
	}
		
		
		
	}

