/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/

package org.apache.kato.tck.tests.legacy;

import java.io.File;
import java.util.List;

import javax.tools.diagnostics.image.CorruptDataException;
import javax.tools.diagnostics.image.DataUnavailable;
import javax.tools.diagnostics.image.ImagePointer;
import javax.tools.diagnostics.image.MemoryAccessException;
import javax.tools.diagnostics.runtime.java.JavaClassLoader;
import javax.tools.diagnostics.runtime.java.JavaHeap;
import javax.tools.diagnostics.runtime.java.JavaMethod;
import javax.tools.diagnostics.runtime.java.JavaMonitor;
import javax.tools.diagnostics.runtime.java.JavaObject;
import javax.tools.diagnostics.runtime.java.JavaReference;
import javax.tools.diagnostics.runtime.java.JavaRuntime;
import javax.tools.diagnostics.runtime.java.JavaVMInitArgs;

import org.apache.kato.tck.harness.TCKJavaRuntimeTestcase;

/**
 * 
 */
public class TestJavaRuntime extends TCKJavaRuntimeTestcase {

	
	public void testCanGetJavaRuntime() {
		
		JavaRuntime runtime=getJavaRuntime();
		assertNotNull(runtime);
		
	}
	
	public void testVersionNotNull() {
		
		JavaRuntime runtime=getJavaRuntime();
		try {
		String version=runtime.getVersion();
		assertNotNull(version);
		} catch(CorruptDataException cde) {
			// allowed under legacy spec - pass test
		}
		
	}
	
	public void testCompiledMethodsNotNull() {
		
		JavaRuntime runtime=getJavaRuntime();
		
		List<JavaMethod> data=runtime.getCompiledMethods();
		assertNotNull(data);
		
	}
	
	public void testHeapRootsNotNull() {
		
		JavaRuntime runtime=getJavaRuntime();
		
		List<JavaReference> data=runtime.getHeapRoots();
		assertNotNull(data);
		
	}

	public void testHeapsNotNull() {
		
		JavaRuntime runtime=getJavaRuntime();
		
		List<JavaHeap> data=runtime.getHeaps();
		assertNotNull(data);
		
	}
public void testClassLoadersNotNull() {
		
		JavaRuntime runtime=getJavaRuntime();
		
		List<JavaClassLoader> data=runtime.getJavaClassLoaders();
		assertNotNull(data);
		
	}

public void testJavaVMNotNull() {
	
	JavaRuntime runtime=getJavaRuntime();
	
	
	try {
		ImagePointer data = runtime.getJavaVM();
		assertNotNull(data);
	} catch (CorruptDataException e) {
		// allowed under spec
	}
	
	
}

public void testJavaVMArgsNotNull() {
	
	JavaRuntime runtime=getJavaRuntime();
	
	
	try {
		JavaVMInitArgs data = runtime.getJavaVMInitArgs();
		assertNotNull(data);
	} catch (CorruptDataException e) {
		// allowed under spec
	} catch (DataUnavailable e) {
		// allowed under spec
	}
	
	
}

public void testMonitorsNotNull() {
	
	JavaRuntime runtime=getJavaRuntime();
	
	List<JavaMonitor> data=runtime.getMonitors();
	assertNotNull(data);
	
}

public void testObjectAtAddress() {
	
	JavaRuntime runtime=getJavaRuntime();
	
	
	try {
		JavaObject data = runtime.getObjectAtAddress(null);
		fail("expected to receive an IllegalArgumentException");
	} catch (CorruptDataException e) {
		// allowed under spec but not expected for a null ptr
		fail("expected to receive an IllegalArgumentException not a CorruptDataException");
	} catch (DataUnavailable e) {
		// allowed under spec but not expected for a null ptr
		fail("expected to receive an IllegalArgumentException not a DataUnavailable");
	} catch (IllegalArgumentException e) {
		// allowed under spec and expected 
		
	} catch (MemoryAccessException e) {
		// allowed under spec but not expected for a null ptr
		fail("expected to receive an IllegalArgumentException not a MemoryAccessException");
	}
	
	
}

public void testGetSourceIsNotNull() {
	JavaRuntime runtime=getJavaRuntime();
	
	File data=runtime.getSource();
	assertNotNull(data);
	
}
}
