/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.tests.junit;


import java.util.Iterator;
import java.util.List;
import java.util.Properties;

import javax.tools.diagnostics.image.CorruptDataException;


public class ImageModuleTest extends AbstractImageTestcase {
	

	/**
	 * Test method for 'javax.tools.diagnostics.image.ImageModule.getName()'
	 * 
	 * Ensures that the name is non-null
	 */
	public void testGetName() {
		try {
			assertNotNull(defaultImageModule().getName());
		} catch (CorruptDataException e) {
			//acceptable
		}
	}

	/**
	 * Test method for 'javax.tools.diagnostics.image.ImageModule.getSections()'
	 * 
	 * Ensures that the sections iterator is non-null and non-empty
	 */
	public void testGetSections() {
		List it = defaultImageModule().getSections();
		
		assertNotNull(it);
		assertFalse(it.isEmpty());
	}

	/**
	 * Test method for 'javax.tools.diagnostics.image.ImageModule.getSymbols()'
	 * 
	 * Ensures that symbols exist in the module
	 * 
	 */
	public void testGetSymbols() {
		List it = defaultImageModule().getSymbols();
		
		assertNotNull(it);
		assertFalse(it.isEmpty());
	}

	/**
	 * Test method for 'javax.tools.diagnostics.image.ImageModule.getProperties()'
	 * 
	 * Ensures that the module has a properties structure
	 */
	public void testGetProperties() {
		Properties props = null;
		
		try {
			props = defaultImageModule().getProperties();
		} catch (CorruptDataException e) {
			assertTrue(false);
		}
		assertNotNull(props);
	}

}
