/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.tests.junit;

import java.util.Iterator;

import javax.tools.diagnostics.image.CorruptDataException;
import javax.tools.diagnostics.image.DataUnavailable;
import javax.tools.diagnostics.image.ImagePointer;
import javax.tools.diagnostics.image.ImageStackFrame;
import javax.tools.diagnostics.image.ImageThread;


public class ImageStackFrameTest extends AbstractImageTestcase
{
	private ImageStackFrame _stackFrame;
	
	public  ImageStackFrame defaultStackFrame()
	{
//		try {
//			return (ImageStackFrame) defaultImageThread().getStackFrames().next();
//		} catch (DataUnavailable e) {
			// Try harder to find a thread with a stack.
			Iterator it = defaultImageProcess().getThreads().iterator();
			while (it.hasNext()) {
				ImageThread thread = (ImageThread) it.next();
				try {
					if (thread.getStackFrames().isEmpty()==false) {
						return (ImageStackFrame) thread.getStackFrames().get(0);
					}
				} catch (DataUnavailable e1) {
					// Ignore
				}
			}
			// although this is accepted by the spec, it has no real meaning for the test so just choose to be unimplemented
			throw new TestNotImplementedException();
//		}
	}
	
	protected void setUp() throws Exception
	{
		_stackFrame = defaultStackFrame();
		super.setUp();
	}

	/**
	 * Test method for 'javax.tools.diagnostics.image.ImageStackFrame.getProcedureAddress()'
	 * 
	 * Ensures that we get a non-null address
	 */
	public void testGetProcedureAddress()
	{
		try {
			ImagePointer address = _stackFrame.getProcedureAddress();
			assertNotNull(address);
		} catch (CorruptDataException e) {
			//accepted
		}
	}

	/**
	 * Test method for 'javax.tools.diagnostics.image.ImageStackFrame.getBasePointer()'
	 * 
	 * Ensures that we get a non-null base pointer
	 */
	public void testGetBasePointer()
	{
		try {
			ImagePointer address = _stackFrame.getBasePointer();
			assertNotNull(address);
			assertTrue(address.getAddress() != 0);
		} catch (CorruptDataException e) {
			//accepted
		}
	}

	/**
	 * Test method for 'javax.tools.diagnostics.image.ImageStackFrame.getProcedureName()'
	 * 
	 * Ensures that we get a non-null, non-empty name
	 */
	public void testGetProcedureName()
	{
		try {
			String name = _stackFrame.getProcedureName();
			assertNotNull(name);
			assertTrue(name.length() > 0);
		} catch (CorruptDataException e) {
			//accepted
		}
	}

}
