/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.katoview.commands.infocommands;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Stack;

import javax.tools.diagnostics.image.CorruptData;
import javax.tools.diagnostics.image.CorruptDataException;
import javax.tools.diagnostics.image.DataUnavailable;
import javax.tools.diagnostics.image.Image;
import javax.tools.diagnostics.image.ImageAddressSpace;
import javax.tools.diagnostics.image.ImageModule;
import javax.tools.diagnostics.image.ImageProcess;
import javax.tools.diagnostics.image.ImageSection;

import org.apache.kato.katoview.Output;
import org.apache.kato.katoview.commands.Command;
import org.apache.kato.katoview.commands.helpers.Exceptions;


public class InfoSymCommand extends Command{
	
	public InfoSymCommand(Output o){
		super(o, "sym", "outputs a list of available modules",
				"parameters: none\n\n" +
				"for each process in the address spaces, outputs a list " +
				"of module sections for each module with their start and " +
				"end addresses, names, and sizes\n");
		child_commands = null;
	}
	
	public void doCommand(Stack args, Image loadedImage, HashMap properties)
	{
		int asnum = 0;
		Iterator itAddressSpace = loadedImage.getAddressSpaces().iterator();
		
		// iterate through the address spaces
		while (itAddressSpace.hasNext()) {
			ImageAddressSpace ias = (ImageAddressSpace)itAddressSpace.next();
			out.print("\n\tlibraries for address space # " + asnum + "\n");
			
			Iterator itProcess = ias.getProcesses().iterator();
			
			// iterate through the processes
			while (itProcess.hasNext())	{
				ImageProcess ip = (ImageProcess)itProcess.next();
				
				out.print("\t process id: ");
				try {
					out.print(ip.getID());
				} catch (DataUnavailable du) {
					out.print(Exceptions.getDataUnavailableString());
				} catch (CorruptDataException cde) {
					out.print(Exceptions.getCorruptDataExceptionString());
				}
				out.print("\n\n");
				
				Iterator iLibs;
				try {
					iLibs = ip.getLibraries().iterator();
				} catch (DataUnavailable du) {
					iLibs = null;
					out.println(Exceptions.getDataUnavailableString());
				} catch (CorruptDataException cde) {
					iLibs = null;
					out.println(Exceptions.getCorruptDataExceptionString());
				}
				
				// iterate through the libraries
				while (null != iLibs && iLibs.hasNext()) {
					Object next = iLibs.next();
					if (next instanceof ImageModule) {
						ImageModule imageModule = (ImageModule)next;
						try {
							out.print("\t  " + imageModule.getName());
						} catch (CorruptDataException cde) {
							out.print("\t  " + Exceptions.getCorruptDataExceptionString());
						}
						out.print(", sections:\n");

						Iterator itSection = imageModule.getSections().iterator();
					
						// iterate through the library sections
						while (itSection.hasNext()) {
							next = itSection.next();
							if (next instanceof ImageSection) {
								ImageSection is = (ImageSection)next;
								out.print("\t   0x" +
									Long.toHexString(is.getBaseAddress().getAddress()) + " - 0x" +
									Long.toHexString(is.getBaseAddress().getAddress() + is.getSize()));
								out.print(", name: \"");
								out.print(is.getName());
								out.print("\", size: 0x");
								out.print(Long.toHexString(is.getSize()));
								out.print("\n");	
							} else if (next instanceof CorruptData) {
								// warn the user that this image section is corrupt
								out.print("\t   <corrupt section encountered>\n");
							} else {
								// unexpected type in iterator
								out.print("\t   <corrupt section encountered>\n");
							}
						}
						out.print("\n");
					
					} else if (next instanceof CorruptData) {
						CorruptData corruptObj = (CorruptData)next;
						// warn the user that this image library is corrupt
						out.print("\t  <corrupt library encountered: " + corruptObj.toString() + ">\n\n");
					} else {
						// unexpected type in iterator
						out.print("\t  <corrupt library encountered>\n\n");
					}
				}
			}
			asnum++;
		}
	}
}
