/*******************************************************************************
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package org.apache.kato.katoview.heapdump;

import java.util.Map;

import org.apache.kato.katoview.Session;


/**
 * Encapsulates the marshalling and unmarshalling of heapdump
 * settings through the properties map.
 * 
 */
public class HeapDumpSettings
{
	public static final String HEAP_DUMP_FILE_PROPERTY = "heap_dump_file";
	public static final String HEAP_DUMP_FORMAT_PROPERTY = "heap_dump_format"; 
	public static final String MULTIPLE_HEAPS_MULTIPLE_FILES_PROPERTY = "heap_dump_multiple_heaps_multiple_files";
	
	public static void setFileName(String fileName,Map properties) 
	{
		properties.put(HEAP_DUMP_FILE_PROPERTY, fileName);
	}
	
	/**
	 * Returns the filename to use for writing out a heap dump, either based
	 * on what the user has set or by generating the default name based on the 
	 * image name
	 */
	public static String getFileName(Map properties)
	{
		String propertyFileName = (String) properties.get(HEAP_DUMP_FILE_PROPERTY);
		
		if(propertyFileName != null) {
			return propertyFileName;
		} else {
			return getDefaultHeapDumpFileName(properties);
		}
	}
	
	private static String getDefaultHeapDumpFileName(Map properties)
	{
		String baseFileName = (String) properties.get(Session.DUMP_FILE_PATH_PROPERTY);
		
		if(areHeapDumpsPHD(properties)) {
			return baseFileName + ".phd";
		} else {
			return baseFileName + ".txt";
		}
	}
	
	public static void setClassicHeapDumps(Map properties)
	{
		properties.put(HEAP_DUMP_FORMAT_PROPERTY, "classic");
	}
	
	public static boolean areHeapDumpsPHD(Map properties) 
	{
		Object formatValue = properties.get(HEAP_DUMP_FORMAT_PROPERTY);
		
		if(formatValue != null && formatValue.equals("classic")) {
			return false;
		} else {
			return true;
		}
	}
	
	public static void setPHDHeapDumps(Map properties)
	{
		properties.put(HEAP_DUMP_FORMAT_PROPERTY, "phd");
	}

	public static void setMultipleHeapsMultipleFiles(Map properties)
	{
		properties.put(MULTIPLE_HEAPS_MULTIPLE_FILES_PROPERTY, "true");
	}
	
	public static void setMultipleHeapsSingleFile(Map properties)
	{
		properties.put(MULTIPLE_HEAPS_MULTIPLE_FILES_PROPERTY, "false");
	}
	
	public static boolean multipleHeapsInMultipleFiles(Map properties)
	{
		Object multipleFilesValue = properties.get(MULTIPLE_HEAPS_MULTIPLE_FILES_PROPERTY);
		
		if(multipleFilesValue == null) {
			return false;
		} else {
			return multipleFilesValue.equals("true");
		}
	}
}
